==> bus-image-6.3.0-sources.jar: org/aoju/bus/image/metric/internal/hl7/HL7ApplicationCache.java <==
/*********************************************************************************
 *                                                                               *
 * The MIT License (MIT)                                                         *
 *                                                                               *
 * Copyright (c) 2015-2021 aoju.org and other contributors.                      *
 *                                                                               *
 * Permission is hereby granted, free of charge, to any person obtaining a copy  *
 * of this software and associated documentation files (the "Software"), to deal *
 * in the Software without restriction, including without limitation the rights  *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     *
 * copies of the Software, and to permit persons to whom the Software is         *
 * furnished to do so, subject to the following conditions:                      *
 *                                                                               *
 * The above copyright notice and this permission notice shall be included in    *
 * all copies or substantial portions of the Software.                           *
 *                                                                               *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     *
 * THE SOFTWARE.                                                                 *
 *                                                                               *
 ********************************************************************************/
package org.aoju.bus.image.metric.internal.hl7;

import org.aoju.bus.core.lang.exception.InstrumentException;
import org.aoju.bus.image.galaxy.ConfigurationCache;

/**
 * @author Kimi Liu
 * @version 6.3.0
 * @since JDK 1.8+
 */
public class HL7ApplicationCache extends ConfigurationCache<HL7Configuration, HL7Application>
        implements IHL7ApplicationCache {

    public HL7ApplicationCache(HL7Configuration conf) {
        super(conf);
    }

    @Override
    protected HL7Application find(HL7Configuration conf, String name)
            throws InstrumentException {
        return conf.findHL7Application(name);
    }

    public HL7Application findHL7Application(String name)
            throws InstrumentException {
        HL7Application ae = get(name);
        if (null == ae)
            throw new InstrumentException("Unknown HL7 Application: " + name);
        return ae;
    }

}

==> bus-image-6.5.2-sources.jar: org/aoju/bus/image/metric/internal/hl7/HL7ApplicationCache.java <==
/*********************************************************************************
 *                                                                               *
 * The MIT License (MIT)                                                         *
 *                                                                               *
 * Copyright (c) 2015-2022 aoju.org and other contributors.                      *
 *                                                                               *
 * Permission is hereby granted, free of charge, to any person obtaining a copy  *
 * of this software and associated documentation files (the "Software"), to deal *
 * in the Software without restriction, including without limitation the rights  *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     *
 * copies of the Software, and to permit persons to whom the Software is         *
 * furnished to do so, subject to the following conditions:                      *
 *                                                                               *
 * The above copyright notice and this permission notice shall be included in    *
 * all copies or substantial portions of the Software.                           *
 *                                                                               *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     *
 * THE SOFTWARE.                                                                 *
 *                                                                               *
 ********************************************************************************/
package org.aoju.bus.image.metric.internal.hl7;

import org.aoju.bus.core.exception.InstrumentException;
import org.aoju.bus.image.galaxy.ConfigurationCache;

/**
 * @author Kimi Liu
 * @since Java 17+
 */
public class HL7ApplicationCache extends ConfigurationCache<HL7Configuration, HL7Application>
        implements IHL7ApplicationCache {

    public HL7ApplicationCache(HL7Configuration conf) {
        super(conf);
    }

    @Override
    protected HL7Application find(HL7Configuration conf, String name)
            throws InstrumentException {
        return conf.findHL7Application(name);
    }

    public HL7Application findHL7Application(String name)
            throws InstrumentException {
        HL7Application ae = get(name);
        if (null == ae)
            throw new InstrumentException("Unknown HL7 Application: " + name);
        return ae;
    }

}
